@@ -136,6 +136,13 @@ public:
      */
     void reload();
 
+    /**
+     * @return Returns a Caption suitable for display to the user. It is
+     * calculated depending on settings, if a search is active and other
+     * factors.
+     */
+    QString caption() const;
+
 public slots:
     /**
      * Sets the current active URL, where all actions are applied. The
@@ -324,6 +331,7 @@ private:
     KUrlNavigator* m_urlNavigator;
     QPushButton* m_emptyTrashButton;
     DolphinSearchBox* m_searchBox;
+    bool m_searchModeEnabled;
     KMessageWidget* m_messageWidget;
 
     DolphinView* m_view;
