@@ -176,8 +176,10 @@ DolphinView::DolphinView(const QUrl& url, QWidget* parent) :
     connect(selectionManager, &KItemListSelectionManager::selectionChanged,
             this, &DolphinView::slotSelectionChanged);
 
+#ifdef HAVE_BALOO
     m_toolTipManager = new ToolTipManager(this);
     connect(m_toolTipManager, &ToolTipManager::urlActivated, this, &DolphinView::urlActivated);
+#endif
 
     m_versionControlObserver = new VersionControlObserver(this);
     m_versionControlObserver->setModel(m_model);
@@ -1031,7 +1033,9 @@ void DolphinView::slotItemHovered(int index)
         const QPoint pos = m_container->mapToGlobal(itemRect.topLeft().toPoint());
         itemRect.moveTo(pos);
 
+#ifdef HAVE_BALOO
         m_toolTipManager->showToolTip(item, itemRect, nativeParentWidget()->windowHandle());
+#endif
     }
 
     emit requestItemInfo(item);
@@ -1408,9 +1412,11 @@ void DolphinView::updateViewState()
 
 void DolphinView::hideToolTip()
 {
+#ifdef HAVE_BALOO
     if (GeneralSettings::showToolTips()) {
         m_toolTipManager->hideToolTip();
     }
+#endif
 }
 
 void DolphinView::calculateItemCount(int& fileCount,
@@ -1482,7 +1488,7 @@ void DolphinView::slotRenamingResult(KJob* job)
 void DolphinView::slotDirectoryLoadingStarted()
 {
     // Disable the writestate temporary until it can be determined in a fast way
-    // in DolphinView::slotLoadingCompleted()
+    // in DolphinView::slotDirectoryLoadingCompleted()
     if (m_isFolderWritable) {
         m_isFolderWritable = false;
         emit writeStateChanged(m_isFolderWritable);
@@ -1563,12 +1569,35 @@ void DolphinView::slotRoleEditingFinished(int index, const QByteArray& role, con
     if (role == "text") {
         const KFileItem oldItem = m_model->fileItem(index);
         const QString newName = value.toString();
-        if (!newName.isEmpty() && newName != oldItem.text() && newName != QLatin1String(".") && newName != QLatin1String("..")) {
+        if (!newName.isEmpty() && newName != oldItem.text() && newName != QLatin1Char('.') && newName != QLatin1String("..")) {
             const QUrl oldUrl = oldItem.url();
 
             QUrl newUrl = oldUrl.adjusted(QUrl::RemoveFilename);
             newUrl.setPath(newUrl.path() + KIO::encodeFileName(newName));
 
+#ifndef Q_OS_WIN
+            //Confirm hiding file/directory by renaming inline
+            if (!hiddenFilesShown() && newName.startsWith(QLatin1Char('.')) && !oldItem.name().startsWith(QLatin1Char('.'))) {
+                KGuiItem yesGuiItem(KStandardGuiItem::yes());
+                yesGuiItem.setText(i18nc("@action:button", "Rename and Hide"));
+
+                const auto code = KMessageBox::questionYesNo(this,
+                                                             oldItem.isFile() ? i18n("Adding a dot to the beginning of this file's name will hide it from view.\n"
+                                                                                     "Do you still want to rename it?")
+                                                                              : i18n("Adding a dot to the beginning of this folder's name will hide it from view.\n"
+                                                                                     "Do you still want to rename it?"),
+                                                             oldItem.isFile() ? i18n("Hide this File?") : i18n("Hide this Folder?"),
+                                                             yesGuiItem,
+                                                             KStandardGuiItem::cancel(),
+                                                             QStringLiteral("ConfirmHide")
+                                                            );
+
+                if (code == KMessageBox::No) {
+                   return;
+                }
+            }
+#endif
+
             const bool newNameExistsAlready = (m_model->index(newUrl) >= 0);
             if (!newNameExistsAlready) {
                 // Only change the data in the model if no item with the new name
